@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # (c) Shrimadhav U K | gautamajay52
+# modified by reaitten/orsixtyone
 
 import logging
 import os
@@ -83,7 +84,7 @@ async def button(bot, update: CallbackQuery):
         else:
             await bot.answer_callback_query(
                 callback_query_id=update.id,
-                text="who are you? 🤪🤔🤔🤔",
+                text="who are you?",
                 show_alert=True,
                 cache_time=0,
             )
@@ -112,7 +113,7 @@ async def button(bot, update: CallbackQuery):
                 "start.sh",
                 "tobrot",
                 "gautam",
-                "tgtlg.txt",
+                "logs.txt",
                 "vendor",
                 "LeechBot.session",
                 "LeechBot.session-journal",
